from .scrap_teams import scrap_teams_by_year
from .scrap_race import scrap_stage, scrap_stage_ttt, scrap_stage_gc, scrap_final_gc, scrap_final_points, \
    scrap_final_kom, scrap_final_youth, scrap_final_teams
